@@ -34,6 +34,8 @@ class GridHandler():
                             '"grid" or "idds"',
                             choices=['grid','idds'],
                             default='grid')
+        parser.add_argument('-p','--search_points', help='json file containing a list of '
+                            'search points to evaluate (for non-idds jobs only)', default=None)
         return parser
 
     def run_parser(self):
@@ -46,13 +48,15 @@ class GridHandler():
                     n_jobs=args.n_jobs,
                     site=args.site,
                     time=args.time,
+                    search_points = args.search_points,
                     mode=args.mode)
     
     @staticmethod
-    def submit(config_input:str, n_jobs=1, site=None, time=-1, mode='grid'):
+    def submit(config_input:str, n_jobs=1, site=None, time=-1, search_points=None, mode='grid'):
         config = GridHandler.preprocess_config(config_input)
         if mode == 'grid':
-            GridHandler.submit_grid(config, n_jobs=n_jobs, site=site, time=time)
+            GridHandler.submit_grid(config, n_jobs=n_jobs, site=site,
+                                    time=time, search_points=search_points)
         elif mode == 'idds':
             GridHandler.submit_idds(config, n_jobs=n_jobs, site=site)
         else:
@@ -92,10 +96,12 @@ class GridHandler():
                 for _ in range(n_jobs):
                     os.system(command)
     @staticmethod
-    def submit_grid(config, n_jobs=1, site=None, time=-1):
+    def submit_grid(config, n_jobs=1, site=None, time=-1, search_points=None):
         project_path = helper.get_project_path(config['project_name'])
         print('INFO: Submitting {} grid job(s)'.format(n_jobs))
-        command = GridHandler.format_grid_command(config, site=site, time=time)
+        command = GridHandler.format_grid_command(config, site=site,
+                                                  time=time,
+                                                  search_points=search_points)
         with helper.cd(project_path):
             # submit jobs
             for _ in range(n_jobs):
@@ -134,7 +140,7 @@ class GridHandler():
         return command
     
     @staticmethod
-    def format_grid_command(config, site=None, time=-1):
+    def format_grid_command(config, site=None, time=-1, search_points=None):
         options = {'forceStaged': '',
                    'useSandbox': '',
                    'noBuild': '',
@@ -144,9 +150,11 @@ class GridHandler():
         proj_name = config['project_name']
         
         options['containerImage'] = grid_config['container']
+        
+        search_points = '' if not search_points else '--search_points {}'.format(search_points)
 
         options['exec'] = '"pip install --upgrade hpogrid && '+\
-                          'hpogrid run {} --mode grid"'.format(proj_name)
+                          'hpogrid run {} --mode grid {}"'.format(proj_name, search_points)
 
         if not grid_config['retry']:
             options['disableAutoRetry'] = ''
